// Cookies.h
/*
Copyright (C) 2003  Anders Hedstrom

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifndef _COOKIES_H
#define _COOKIES_H

#ifdef _WIN32
#define STL_USING_LIST
#include <stlhelper.h>
#else
#include <list>
#endif


//! Store the cookies name/value pairs.

typedef struct cookiestruct
{
//	struct cookiestruct *next; //!< Linked list ptr to next in list 
	char *name; //!< Cookie name
	char *value; //!< Cookie value
} COOKIE;
typedef std::list<COOKIE *> cookie_v;

//! Retrieve and manage cookies during a cgi call.

class Cookies {
public:
	/**
	 * Default constructor (used in POST operations).
	 * Input is read from stdin.
	*/
	Cookies(void);
	/**
	 * Another constructor (used in GET operations).
	 * Input is read from the environment variable QUERY_STRING
	 * with a length of CONTENT_LENGTH.
	 * @param query_string The httpd server provided QUERY_STRING
	*/
	Cookies(char *query_string);
	/**
	 * Destructor.
	*/
	~Cookies(void);
	int getvalue(char *,char *,short); // (name, buffer, length)
	void replacevalue(char *,char *);
	void replacevalue(char *,long);
	void replacevalue(char *,int);
	int getlength(char *);
	void setcookie(char *,char *,char *,char *);
	void setcookie(char *,char *,char *,long);
	void setcookie(char *,char *,char *,int);
	void expiredatetime(char *);

	cookie_v& GetCookies() { return m_cookies; }

private:
//	COOKIE *cookiebase;
	cookie_v m_cookies;
};

#endif // _COOKIES_H
