// Web.h
/*
Copyright (C) 2003  Anders Hedstrom

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifndef _WEB_H
#define _WEB_H

#ifdef _WIN32
#define STL_USING_STRING
#define STL_USING_LIST
#include <stlhelper.h>
#else
#include <string>
#include <list>
#endif


class Form;
class Cookies;

//! The CGI main class

class Web 
{
public:
	Web();
	/** @param cd cookie domain
	    @param cp cookie path
	    @Param id input data filename
	*/
	Web(const std::string &cd,const std::string &cp,const std::string& id = "");
	/** @param cd cookie domain
	    @param cp cookie path
	    @Param id input data filename
	*/
	Web(int argc,char *argv[],const std::string &cd,const std::string &cp,const std::string& id = "");
	virtual ~Web();

	/** @param id input data filename */
	void Init(const std::string& id);

	void SetCookieDomain(const std::string &);
	void SetCookiePath(const std::string &);
	void SetCookie(const std::string &name,const std::string &value);
	void SetCookie(const std::string &name,long value);
	void SetCookie(const std::string &name,int value);
	void Execute();
	void SetCgiName(const std::string &);
	std::string GetCgiName();
	Form *GetForm();
	Cookies *GetCookies();

	void RegWebForm(WebForm *);

	virtual void ReadCookies();
	virtual void FormInput();
	virtual void CreateHeader();
	virtual void GenerateDocument();

	std::string GetDate();
	std::string GetRequestMethod();
	void UpdateModified(const std::string& );
	std::string datetime2httpdate(const std::string& dt);
	const std::string& GetLastModified() { return m_lastmodified; }
	const std::string& GetQueryString() { return m_query_string; }

protected:
	Form *m_pclForm;
	Cookies *m_pclCookies;

private:
	Web(const Web& ) {}
	Web& operator=(const Web& ) { return *this; }
	std::string m_strCookieDomain;
	std::string m_strCookiePath;
	std::string m_strCgiName;
	std::list<WebForm *> m_forms;
	std::string m_date;
	std::string m_method; // request_method
	std::string m_lastmodified;
	std::string m_query_string;
};


#endif // _WEB_H
